//==============================================================================
//
//   DefaultParameterDialog.java
//
//   Copyright (c) 2001-2003 Graffiti Team, Uni Passau
//
//==============================================================================
// $Id: DefaultParameterDialog.java,v 1.2 2003/08/02 09:19:56 holleis Exp $

package org.graffiti.editor.dialog;

import java.awt.BorderLayout;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowEvent;
import java.awt.event.WindowListener;

import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;

import org.graffiti.core.ImageBundle;
import org.graffiti.core.StringBundle;

import org.graffiti.editor.MainFrame;

import org.graffiti.managers.EditComponentManager;

import org.graffiti.plugin.parameter.Parameter;

import org.graffiti.selection.Selection;

/**
 * The default implementation of a parameter dialog.
 *
 * @version $Revision: 1.2 $
 */
public class DefaultParameterDialog
    extends AbstractParameterDialog
    implements ActionListener, WindowListener
{
    //~ Instance fields ========================================================

    /** The <code>ImageBundle</code> of the view type chooser. */
    protected ImageBundle iBundle = ImageBundle.getInstance();

    /** The panel used to display and change parameter values. */
    protected ParameterEditPanel paramEditPanel;

    /** The <code>StringBundle</code> of the view type chooser. */
    protected StringBundle sBundle = StringBundle.getInstance();

    /** The list of parameters, the user is editing. */
    protected Parameter[] params;

    /** The value edit component manager, the edit panel needs. */
    private EditComponentManager editComponentManager;

    /** The dialog's buttons. */
    private JButton cancel;

    /** The dialog's buttons. */
    private JButton ok;

    /** The description of this dialog. */
    private JLabel description;

    /** The panel, which contains the parameters. */
    private JPanel paramsPanel;

    /** <code>true</code>, if the user selected the ok button in this dialog. */
    private boolean selectedOk = false;

    //~ Constructors ===========================================================

    /**
     * Constructor for DefaultParameterDialog.
     *
     * @param editComponentManager DOCUMENT ME!
     * @param parent the parent of this dialog.
     * @param parameters the array of parameters to edit in this dialog.
     * @param selection DOCUMENT ME!
     * @param algorithmName the name of the algorithm, to edit the parameters
     *        for.
     */
    public DefaultParameterDialog(EditComponentManager editComponentManager,
        MainFrame parent, Parameter[] parameters, Selection selection,
        String algorithmName)
    {
        super(parent, true);

        this.editComponentManager = editComponentManager;

        this.params = parameters;

        getContentPane().setLayout(new BorderLayout());

        setTitle(algorithmName);
        setSize(420, 320);
        setResizable(false);

        ok = new JButton(sBundle.getString("run.dialog.button.run"));
        cancel = new JButton(sBundle.getString("run.dialog.button.cancel"));
        description = new JLabel(sBundle.getString("run.dialog.desc"));

        JPanel buttonsPanel = new JPanel();

        buttonsPanel.add(ok);
        buttonsPanel.add(cancel);

        paramsPanel = createValueEditContainer(params, selection);

        ok.setEnabled(true);

        getRootPane().setDefaultButton(ok);

        defineLayout();
        addListeners();

        pack();
        setLocationRelativeTo(parent);
        show();
    }

    //~ Methods ================================================================

    /**
     * @see org.graffiti.editor.dialog.ParameterDialog#getEditedParameters()
     */
    public Parameter[] getEditedParameters()
    {
        return this.paramEditPanel.getUpdatedParameters();
    }

    /**
     * DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public boolean isOkSelected()
    {
        return selectedOk;
    }

    /**
     * @see java.awt.event.ActionListener#actionPerformed(ActionEvent)
     */
    public void actionPerformed(ActionEvent e)
    {
        Object src = e.getSource();

        if(src == cancel)
        {
            dispose();
        }
        else if(src == ok)
        {
            okSelected();
        }
    }

    /**
     * @see java.awt.event.WindowListener#windowActivated(WindowEvent)
     */
    public void windowActivated(WindowEvent arg0)
    {
    }

    /**
     * @see java.awt.event.WindowListener#windowClosed(WindowEvent)
     */
    public void windowClosed(WindowEvent arg0)
    {
    }

    /**
     * @see java.awt.event.WindowListener#windowClosing(WindowEvent)
     */
    public void windowClosing(WindowEvent arg0)
    {
        dispose();
    }

    /**
     * @see java.awt.event.WindowListener#windowDeactivated(WindowEvent)
     */
    public void windowDeactivated(WindowEvent arg0)
    {
    }

    /**
     * @see java.awt.event.WindowListener#windowDeiconified(WindowEvent)
     */
    public void windowDeiconified(WindowEvent arg0)
    {
    }

    /**
     * @see java.awt.event.WindowListener#windowIconified(WindowEvent)
     */
    public void windowIconified(WindowEvent arg0)
    {
    }

    /**
     * @see java.awt.event.WindowListener#windowOpened(WindowEvent)
     */
    public void windowOpened(WindowEvent arg0)
    {
    }

    /**
     * Adds the listeners to the dialog.
     */
    private void addListeners()
    {
        cancel.addActionListener(this);
        ok.addActionListener(this);
        addWindowListener(this);
    }

    /**
     * Creates and returns a value edit container for the given parameters.
     *
     * @param parameters the list of parameters, the user wants to edit.
     * @param selection DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    private JPanel createValueEditContainer(Parameter[] parameters,
        Selection selection)
    {
        this.paramEditPanel = new ParameterEditPanel(parameters,
                editComponentManager.getEditComponents(), selection);

        return this.paramEditPanel;
    }

    /**
     * Defines the layout of this dialog.
     */
    private void defineLayout()
    {
        getContentPane().setLayout(new GridBagLayout());

        GridBagConstraints labelConstraints = new GridBagConstraints();
        labelConstraints.gridx = 0;
        labelConstraints.gridy = 0;
        labelConstraints.gridwidth = 1;
        labelConstraints.gridheight = 1;
        labelConstraints.fill = GridBagConstraints.BOTH;
        labelConstraints.anchor = GridBagConstraints.WEST;
        labelConstraints.weightx = 1.0;
        labelConstraints.weighty = 0.0;
        labelConstraints.insets = new Insets(8, 8, 0, 8);
        getContentPane().add(description, labelConstraints);

        GridBagConstraints listConstraints = new GridBagConstraints();
        listConstraints.gridx = 0;
        listConstraints.gridy = 1;
        listConstraints.gridwidth = 4;
        listConstraints.gridheight = 1;
        listConstraints.fill = GridBagConstraints.BOTH;
        listConstraints.anchor = GridBagConstraints.CENTER;
        listConstraints.weightx = 1.0;
        listConstraints.weighty = 1.0;
        listConstraints.insets = new Insets(8, 8, 8, 8);
        getContentPane().add(paramsPanel, listConstraints);

        GridBagConstraints okConstraints = new GridBagConstraints();
        okConstraints.gridx = 2;
        okConstraints.gridy = 2;
        okConstraints.gridwidth = 1;
        okConstraints.gridheight = 1;
        okConstraints.anchor = GridBagConstraints.EAST;
        okConstraints.insets = new Insets(0, 8, 8, 8);
        getContentPane().add(ok, okConstraints);

        GridBagConstraints cancelConstraints = new GridBagConstraints();
        cancelConstraints.gridx = 3;
        cancelConstraints.gridy = 2;
        cancelConstraints.gridwidth = 1;
        cancelConstraints.gridheight = 1;
        cancelConstraints.anchor = GridBagConstraints.EAST;
        cancelConstraints.insets = new Insets(0, 8, 8, 8);
        getContentPane().add(cancel, cancelConstraints);
    }

    /**
     * DOCUMENT ME!
     */
    private void okSelected()
    {
        selectedOk = true;
        System.out.println("ok selected");
        dispose();
    }
}

//------------------------------------------------------------------------------
//   end of file
//------------------------------------------------------------------------------
