//==============================================================================
//
//   LabelAttribute.java
//
//   Copyright (c) 2001-2003 Graffiti Team, Uni Passau
//
//==============================================================================
// $Id: LabelAttribute.java,v 1.6 2003/09/15 11:49:08 holleis Exp $

package org.graffiti.graphics;

import java.util.Iterator;
import java.util.Map;

import org.graffiti.attributes.Attribute;
import org.graffiti.attributes.HashMapAttribute;
import org.graffiti.attributes.StringAttribute;

/**
 * Contains the graphic attribute label
 *
 * @version $Revision: 1.6 $
 */
public class LabelAttribute
    extends HashMapAttribute
    implements GraphicAttributeConstants {
    //~ Instance fields ========================================================

    /** Holds color of label text. */
    protected ColorAttribute textcolor;

    //    /**
    //     * Position of the label within this graph element.
    //     */
    //    protected PositionAttribute position;

    /** Alignment of the label text */
    protected StringAttribute alignment;

    /** Holds font of label text. */
    protected StringAttribute font;

    /** Holds the name of the label. */
    protected StringAttribute label;

    //~ Constructors ===========================================================

    /**
     * Constructor for Label.
     *
     * @param id the id of the attribute.
     */
    public LabelAttribute(String id) {
        super(id);
        this.label = new StringAttribute(LABEL, "");

        //        this.position = new PositionAttribute(POSITION);
        this.alignment = new StringAttribute(ALIGNMENT, "");
        this.alignment.setDescription("A string constant describing " +
            "predefined positions of the label.");
        this.font = new StringAttribute(FONT, "");
        this.textcolor = new ColorAttribute(TEXTCOLOR, java.awt.Color.BLACK);
        add(this.label, false);

        //        add(this.position, false);
        add(this.alignment, false);
        add(this.font, false);
        add(this.textcolor, false);
    }

    /**
     * Constructor for Label.
     *
     * @param id the id of the attribute.
     * @param l the label-value of the attribute.
     */
    public LabelAttribute(String id, String l) {
        super(id);
        this.label = new StringAttribute(LABEL, l);

        //        this.position = new PositionAttribute(POSITION);
        this.alignment = new StringAttribute(ALIGNMENT, "");
        this.alignment.setDescription("A string constant describing " +
            "predefined positions of the label.");
        this.font = new StringAttribute(FONT, "");
        this.textcolor = new ColorAttribute(TEXTCOLOR, java.awt.Color.BLACK);
        add(this.label, false);

        //        add(this.position, false);
        add(this.alignment, false);
        add(this.font, false);
        add(this.textcolor, false);
    }

    /**
     * Constructor for Label.
     *
     * @param id the id of the attribute.
     * @param l the label-value of the attribute.
     * @param p the position-value of the attribute.
     * @param a the alignment-value of the attribute.
     * @param f the font-value of the attribute.
     * @param tc the textcolor-value of the attribute.
     */
    public LabelAttribute(String id, String l, PositionAttribute p, String a,
        String f, ColorAttribute tc) {
        super(id);
        this.label = new StringAttribute(LABEL, l);

        //        this.position = (PositionAttribute) p.copy();
        this.alignment = new StringAttribute(ALIGNMENT, a);
        this.alignment.setDescription("A string constant describing " +
            "predefined positions of the label.");
        this.font = new StringAttribute(FONT, f);
        this.textcolor = new ColorAttribute(TEXTCOLOR, tc.getColor());
        add(this.label, false);

        //        add(this.position, false);
        add(this.alignment, false);
        add(this.font, false);
        add(this.textcolor, false);
    }

    /**
     * Constructor for Label.
     *
     * @param id the id of the attribute.
     * @param l the label-value of the attribute.
     * @param p the position-value of the attribute.
     * @param a the alignment-value of the attribute.
     * @param f the font-value of the attribute.
     * @param tc the textcolor-value of the attribute.
     */
    public LabelAttribute(String id, StringAttribute l, PositionAttribute p,
        StringAttribute a, StringAttribute f, ColorAttribute tc) {
        super(id);
        this.label = new StringAttribute(LABEL, l.getString());

        //        this.position = (PositionAttribute) p.copy();
        this.alignment = new StringAttribute(ALIGNMENT, a.getString());
        this.alignment.setDescription("A string constant describing " +
            "predefined positions of the label.");
        this.font = new StringAttribute(FONT, f.getString());
        this.textcolor = tc;
        add(this.label, false);

        //        add(this.position, false);
        add(this.alignment, false);
        add(this.font, false);
        add(this.textcolor, false);
    }

    /**
     * Constructor for Label.
     *
     * @param id the id of the attribute.
     * @param l the label-value of the attribute.
     * @param p the position-value of the attribute.
     * @param a the alignment-value of the attribute.
     * @param f the font-value of the attribute.
     * @param tc the textcolor-value of the attribute.
     */
    public LabelAttribute(String id, String l, PositionAttribute p, String a,
        String f, java.awt.Color tc) {
        super(id);
        this.label = new StringAttribute(LABEL, l);

        //        this.position = (PositionAttribute) p.copy();
        this.alignment = new StringAttribute(ALIGNMENT, a);
        this.alignment.setDescription("A string constant describing " +
            "predefined positions of the label.");
        this.font = new StringAttribute(FONT, f);
        this.textcolor = new ColorAttribute(TEXTCOLOR, tc);
        add(this.label, false);

        //        add(this.position, false);
        add(this.alignment, false);
        add(this.font, false);
        add(this.textcolor, false);
    }

    //~ Methods ================================================================

    //    /**
    //     * Sets the 'position'-value.
    //     *
    //     * @param p the 'position'-value to be set.
    //     */
    //    public void setPosition(PositionAttribute p) {
    //		position.setCollection(p.getCollection());
    ////        position.setAlignment(p.getAlignment());
    ////        position.setHorizontal(p.getHorizontal());
    ////        position.setVertical(p.getVertical());
    //    }

    /**
     * Sets the 'alignment'-value.
     *
     * @param a the 'alignment'-value to be set.
     */
    public void setAlignment(String a) {
        this.alignment.setString(a);
    }

    //    /**
    //     * Returns the 'position'-value of the encapsulated label.
    //     *
    //     * @return the 'position'-value of the encapsulated label.
    //     */
    //    public PositionAttribute getPosition() {
    //        return this.position;
    //    }

    /**
     * Returns the 'alignment'-value of the encapsulated label.
     *
     * @return the 'alignment'-value of the encapsulated label.
     */
    public String getAlignment() {
        return this.alignment.getString();
    }

    /**
     * Sets the collection of attributes contained within this
     * <tt>CollectionAttribute</tt>
     *
     * @param attrs the map that contains all attributes.
     *
     * @throws IllegalArgumentException DOCUMENT ME!
     */
    public void setCollection(Map attrs) {
        if(attrs.keySet().contains(LABEL) &&
            attrs.keySet().contains(ALIGNMENT) &&
            attrs.keySet().contains(FONT) &&
            attrs.keySet().contains(TEXTCOLOR)) {
            for(Iterator it = attrs.keySet().iterator(); it.hasNext();) {
                String attrId = (String) it.next();

                if(attrId.equals(LABEL)) {
                    setLabel(((StringAttribute) attrs.get(LABEL)).getString());

                    //                } else if (attrId.equals(POSITION)) {
                    //                    setPosition((PositionAttribute) attrs.get(POSITION));
                } else if(attrId.equals(ALIGNMENT)) {
                    setAlignment(((StringAttribute) attrs.get(ALIGNMENT)).getString());
                } else if(attrId.equals(FONT)) {
                    setFont(((StringAttribute) attrs.get(FONT)).getString());
                } else if(attrId.equals(TEXTCOLOR)) {
                    setTextcolor((ColorAttribute) attrs.get(TEXTCOLOR));
                } else {
                    this.add((Attribute) attrs.get(it.next()));
                }
            }
        } else {
            throw new IllegalArgumentException("Invalid value type.");
        }
    }

    /**
     * Sets the 'font'-value.
     *
     * @param f the 'font'-value to be set.
     */
    public void setFont(String f) {
        this.font.setString(f);
    }

    /**
     * Returns the 'font'-value of the encapsulated label.
     *
     * @return the 'font'-value of the encapsulated label.
     */
    public String getFont() {
        return this.font.getString();
    }

    /**
     * Sets the 'label'-value.
     *
     * @param l the 'label'-value to be set.
     */
    public void setLabel(String l) {
        this.label.setString(l);
    }

    /**
     * Returns the 'label'-value of the encapsulated label.
     *
     * @return the 'label'-value of the encapsulated label.
     */
    public String getLabel() {
        return this.label.getString();
    }

    /**
     * Set the 'textcolor'-value.
     *
     * @param tc the 'textcolor'-value to be set.
     */
    public void setTextcolor(ColorAttribute tc) {
        textcolor.setColor(tc.getColor());
    }

    /**
     * Returns the 'textcolor'-value of the encapsulated label.
     *
     * @return the 'textcolor'-value of the encapsulated label.
     */
    public ColorAttribute getTextcolor() {
        return this.textcolor;
    }

    /**
     * Returns a deep copy of this object.
     *
     * @return A deep copy of this object.
     */
    public Object copy() {
        LabelAttribute copied = new LabelAttribute(this.getId());
        copied.setLabel(new String(this.getLabel()));

        //        copied.setPosition((PositionAttribute) this.getPosition().copy());
        copied.setAlignment(new String(this.getAlignment()));
        copied.setFont(new String(this.getFont()));
        copied.setTextcolor((ColorAttribute) this.getTextcolor().copy());

        return copied;
    }

    //    /**
    //     * Sets the value of this <code>Attribute</code> to the given value without
    //     * informing the <code>ListenerManager</code>.
    //     *
    //     * @param v the new value.
    //     *
    //     * @exception IllegalArgumentException if <code>v</code> is not of the
    //     *            apropriate type.
    //     */
    //    protected void doSetValue(Object v)
    //        throws IllegalArgumentException
    //    {
    //        LabelAttribute labelAttr = null;
    //
    //        try
    //        {
    //            labelAttr = (LabelAttribute) v;
    //        }
    //        catch(ClassCastException cce)
    //        {
    //            throw new IllegalArgumentException("Invalid value type.");
    //        }
    //
    //        this.label = new StringAttribute(LABEL, labelAttr.getLabel());
    //
    //        //        this.position =
    //        //            (PositionAttribute) ((LabelAttribute) v).getPosition().copy();
    //        this.alignment = new StringAttribute(ALIGNMENT, labelAttr.getAlignment());
    //        this.alignment.setDescription("A string constant describing " +
    //            "predefined positions of the label.");
    //        this.font = new StringAttribute(FONT, labelAttr.getFont());
    //        this.textcolor = (ColorAttribute) labelAttr.getTextcolor().copy();
    //    }
}

//------------------------------------------------------------------------------
//   end of file
//------------------------------------------------------------------------------
