//==============================================================================
//
//   AbstractDialogableEditComponent.java
//
//   Copyright (c) 2001-2003 Graffiti Team, Uni Passau
//
//==============================================================================
// $Id: AbstractDialogableEditComponent.java,v 1.2 2003/08/02 09:19:56 holleis Exp $

package org.graffiti.plugin.editcomponent;

import javax.swing.JButton;
import javax.swing.JDialog;

import org.graffiti.plugin.Displayable;

/**
 * <code>AbstractDialogableEditComponent</code> provides some default
 * extensions of the <code>AbstractValueEditComponent</code> for those
 * instances of <code>ValueEditComponent</code> which offer an arbitrary
 * dialog for specifying the corresponding attribute value.
 *
 * @see javax.swing.JButton
 * @see javax.swing.JDialog
 */
public abstract class AbstractDialogableEditComponent
    extends AbstractValueEditComponent
{
    //~ Instance fields ========================================================

    /** The button for opening the dialog. */
    protected JButton button;

    /** The dialog for specifying the value. */
    protected JDialog dialog;

    //~ Constructors ===========================================================

    /**
     * Constructs a new <code>AbstractDialogableEditComponent</code>.
     *
     * @param disp DOCUMENT ME!
     */
    protected AbstractDialogableEditComponent(Displayable disp)
    {
        super(disp);
    }

    //~ Methods ================================================================

    /**
     * Returns the button of the <code>AbstractDialogableEditComponent</code>.
     *
     * @return the button of the <code>AbstractDialogableEditComponent</code>.
     */
    public JButton getButton()
    {
        return this.button;
    }

    /**
     * Returns the dialog of this <code>AbstractDialogableEditComponent</code>.
     *
     * @return the dialog of this <code>AbstractDialogableEditComponent</code>.
     */
    public JDialog getDialog()
    {
        return this.dialog;
    }
}

//------------------------------------------------------------------------------
//   end of file
//------------------------------------------------------------------------------
