//==============================================================================
//
//   InputSerializer.java
//
//   Copyright (c) 2001-2003 Graffiti Team, Uni Passau
//
//==============================================================================
// $Id: InputSerializer.java,v 1.3 2003/09/10 15:02:53 holleis Exp $

package org.graffiti.plugin.io;

import java.io.IOException;
import java.io.InputStream;
import java.net.URL;

import org.graffiti.graph.Graph;

/**
 * Interfaces a serializer, which is able to reconstruct a graph from a given
 * input.
 *
 * @version $Revision: 1.3 $
 */
public interface InputSerializer
    extends Serializer
{
    //~ Methods ================================================================

    /**
     * Reads in a graph from the given filename.
     *
     * @param filename The name of the file to read the graph from.
     * @param g The graph to add the newly read graph to.
     *
     * @exception IOException If an IO error occurs.
     */
    public void read(String filename, Graph g)
        throws IOException;

    /**
     * Reads in the graph from the given url.
     *
     * @param url The URL to read the graph from.
     * @param g The graph to add the newly read graph to.
     *
     * @exception IOException If an IO error occurs.
     */
    public void read(URL url, Graph g)
        throws IOException;

    /**
     * Reads in a graph from the given input stream.
     *
     * @param in The input stream to read the graph from.
     * @param g The graph to add the newly read graph to.
     *
     * @exception IOException If an IO error occurs.
     */
    public void read(InputStream in, Graph g)
        throws IOException;

    /**
     * Reads in a graph from the given input stream.
     *
     * @param in The input stream to read the graph from.
     * @return The newly read graph.
     *
     * @exception IOException If an IO error occurs.
     */
    public Graph read(InputStream in)
        throws IOException;
}

//------------------------------------------------------------------------------
//   end of file
//------------------------------------------------------------------------------
