//==============================================================================
//
//   AddNodeEdit.java
//
//   Copyright (c) 2001-2003 Graffiti Team, Uni Passau
//
//==============================================================================
// $Id: AddNodeEdit.java,v 1.6 2003/11/03 12:37:17 forster Exp $

package org.graffiti.undo;

import java.util.Map;

import org.graffiti.graph.Graph;
import org.graffiti.graph.Node;

/**
 * Class <code>AddNodeEdit</code> makes the add node action undoable.
 *
 * @author Walter Wirch
 * @version $Revision: 1.6 $
 */
public class AddNodeEdit
    extends GraphElementsEdit {
    //~ Instance fields ========================================================

    /** added node */
    private Node node;

    //~ Constructors ===========================================================

    /**
     * Constructor for AddNodeEdit.
     *
     * @param node
     * @param graph
     * @param geMap
     */
    public AddNodeEdit(Node node, Graph graph, Map geMap) {
        super(graph, geMap);
        this.node = node;
    }

    //~ Methods ================================================================

    /**
     * Used to display the name for this edit.
     *
     * @return the name of this edit.
     *
     * @see javax.swing.undo.UndoableEdit
     */
    public String getPresentationName() {
        return sBundle.getString("undo.addNode");
    }
/*
 * @see org.graffiti.undo.GraffitiAbstractUndoableEdit#execute()
 */
public void execute() {
    }

    /**
     * Adds the same node that was added through the method that created this
     * edit.
     */
    public void redo() {
        super.redo();

        Node newNode = graph.addNodeCopy(node);
        geMap.put(node, newNode);
    }

    /**
     * Deletes the node that is stored in this edit.
     */
    public void undo() {
        super.undo();

        node = (Node) getCurrentGraphElement(node);
        graph.deleteNode(node);
    }
}

//------------------------------------------------------------------------------
//   end of file
//------------------------------------------------------------------------------
